@@ -36,12 +36,20 @@ import Test.QuickCheck hiding -- for re-export
   , verboseCheckWithResult
   , verboseCheckResult
   , verbose
+  -- Template Haskell functions
+#if MIN_VERSION_QuickCheck(2,11,0)
+  , allProperties
+#endif
+  , forAllProperties
+  , quickCheckAll
+  , verboseCheckAll
   )
 
 import Data.Typeable
 import Data.List
 import Text.Printf
 import Test.QuickCheck.Random (mkQCGen)
+import Options.Applicative (metavar)
 import System.Random (getStdRandom, randomR)
 #if !MIN_VERSION_base(4,8,0)
 import Control.Applicative
@@ -92,6 +100,7 @@ instance IsOption QuickCheckTests where
   parseValue = fmap QuickCheckTests . safeRead
   optionName = return "quickcheck-tests"
   optionHelp = return "Number of test cases for QuickCheck to generate"
+  optionCLParser = mkOptionCLParser $ metavar "NUMBER"
 
 instance IsOption QuickCheckReplay where
   defaultValue = QuickCheckReplay Nothing
@@ -99,12 +108,14 @@ instance IsOption QuickCheckReplay where
   parseValue v = QuickCheckReplay . Just <$> safeRead v
   optionName = return "quickcheck-replay"
   optionHelp = return "Random seed to use for replaying a previous test run (use same --quickcheck-max-size)"
+  optionCLParser = mkOptionCLParser $ metavar "SEED"
 
 instance IsOption QuickCheckShowReplay where
   defaultValue = QuickCheckShowReplay False
-  parseValue = fmap QuickCheckShowReplay . safeRead
+  parseValue = fmap QuickCheckShowReplay . safeReadBool
   optionName = return "quickcheck-show-replay"
   optionHelp = return "Show a replay token for replaying tests"
+  optionCLParser = flagCLParser Nothing (QuickCheckShowReplay True)
 
 defaultMaxSize :: Int
 defaultMaxSize = QC.maxSize QC.stdArgs
@@ -114,16 +125,18 @@ instance IsOption QuickCheckMaxSize where
   parseValue = fmap QuickCheckMaxSize . safeRead
   optionName = return "quickcheck-max-size"
   optionHelp = return "Size of the biggest test cases quickcheck generates"
+  optionCLParser = mkOptionCLParser $ metavar "NUMBER"
 
 instance IsOption QuickCheckMaxRatio where
   defaultValue = fromIntegral $ QC.maxDiscardRatio QC.stdArgs
   parseValue = fmap QuickCheckMaxRatio . safeRead
   optionName = return "quickcheck-max-ratio"
   optionHelp = return "Maximum number of discared tests per successful test before giving up"
+  optionCLParser = mkOptionCLParser $ metavar "NUMBER"
 
 instance IsOption QuickCheckVerbose where
   defaultValue = QuickCheckVerbose False
-  parseValue = fmap QuickCheckVerbose . safeRead
+  parseValue = fmap QuickCheckVerbose . safeReadBool
   optionName = return "quickcheck-verbose"
   optionHelp = return "Show the generated test cases"
   optionCLParser = mkFlagCLParser mempty (QuickCheckVerbose True)
